@@ -1,13 +1,11 @@
 import matplotlib.pyplot as plt
 
-def printData():
+def printData(x_list,y_list):
     print("+-------------------------------+")
     x_label=input("|  请输入x轴英文名称:\t")
     y_label=input("|  请输入y轴英文名称:\t")
     title=  input("|  标题的英文是:     \t")
     print("+-------------------------------+")
-    x_list = eval(input("|  请输入x坐标的数据列表[]:"))
-    y_list = eval(input("|  请输入y坐标的数据列表[]:"))
     plt.plot(x_list,y_list)
     plt.xlabel(x_label)
     plt.ylabel(y_label)
@@ -35,8 +33,7 @@ def printNpic():
         plt.ylabel(y_label)
         plt.title(title)
         plt.grid()
-    plt.show()
     print("+-------------------------------+")
+    plt.show()
 
-printNpic()
 
